@@ -493,7 +493,7 @@ class Model:
         """
         Documentation
         """
-        self.__data = data
+        self.__data = copy(data)
         self.restyle()
         for variable in self.variables:
             if variable.name in self.data:
